# This file is part of SSHare.
#
# SSHare is free software: you can redistribute it and/or modify it under the terms of
# the GNU General Public License as published by the Free Software Foundation,
# either version 3 of the License, or (at your option) any later version.
#
# SSHare is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# SSHare. If not, see <https://www.gnu.org/licenses/>.

import getpass
import subprocess

from ..config import NoDefault
from ..source import File
from ..source import Raw

plugin_type = "upload"

config = {
    "host": NoDefault,
    "path": NoDefault,
    "port": 22,
    "user": getpass.getuser(),
}

def upload(name, source):
    logger.info(f"Uploading to {config.user}@{config.host}:{config.path}/{name} on port {config.port}")
    if isinstance(source, File):
        command = [
            "scp",
        ] + ([
            "-r",
        ] if source.path.is_dir() else []) + [
            "-P", f"{config.port}",
            source.path,
            f"{config.user}@{config.host}:{config.path}/{name}",
        ]
        process = subprocess.run(command)
        if process.returncode != 0:
            if source.path.is_dir():
                logger.fatal("Error: failed to upload directory")
            else:
                logger.fatal("Error: failed to upload file")
    elif isinstance(source, Raw):
        command = [
            "ssh",
            f"-p {config.port}",
            f"{config.user}@{config.host}",
            "-T",
            f"cat > {config.path}/{name}"
        ]
        process = subprocess.run(
            command,
            input = source.data,
        )
        if process.returncode != 0:
            logger.fatal("Error: failed to upload data")
